@@ -6,7 +6,7 @@ package Map::Metro;
 
 # ABSTRACT: Public transport graphing
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.2400';
+our $VERSION = '0.2401';
 
 use Map::Metro::Elk;
 use Module::Pluggable search_path => ['Map::Metro::Plugin::Map'], require => 1, sub_name => 'system_maps';
@@ -141,8 +141,8 @@ Map::Metro - Public transport graphing
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Map-Metro"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Map-Metro-0.2400"><img src="https://badgedepot.code301.com/badge/kwalitee/Map-Metro/0.2400" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Map-Metro%200.2400"><img src="https://badgedepot.code301.com/badge/cpantesters/Map-Metro/0.2400" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Map-Metro-0.2401"><img src="https://badgedepot.code301.com/badge/kwalitee/Map-Metro/0.2401" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Map-Metro%200.2401"><img src="https://badgedepot.code301.com/badge/cpantesters/Map-Metro/0.2401" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-61.6%-red.svg" alt="coverage 61.6%" />
 </p>
 
@@ -150,7 +150,7 @@ Map::Metro - Public transport graphing
 
 =head1 VERSION
 
-Version 0.2400, released 2016-02-24.
+Version 0.2401, released 2016-02-25.
 
 =head1 SYNOPSIS
 
@@ -224,13 +224,11 @@ The following rules are a guideline:
 
 If the starting station and finishing station...
 
-...is on the same line there will be no transfers to other lines.
+...are on the same line there will be no changes to other lines.
 
 ...shares multiple lines (e.g., both stations are on both line 2 and 4), each line constitutes a route.
 
-...are on different lines a transfer will take place at a shared station. No matter how many shared stations there are, there will only be one route returned (but which transfer station is used can differ between queries).
-
-...has no shared stations, the shortest route/routes will be returned.
+...are on different lines, line changes will take place at suitable station(s). There is no guarantee that the same stations will be chosen for line changes between searches, if there are more than one suitable station to make a change at.
 
 =head1 MORE INFORMATION
 
@@ -264,8 +262,8 @@ L<Map::Metro::Graph::Transfer> - Defines a MMG::Transfer.
 
 The following is a conceptual overview of the various parts of a graph:
 
-At first, the map file is parsed. The four types of blocks (stations, transfers, lines and segments) are translated
-into their respective object.
+At first, the map file is parsed. The four types of information (stations, transfers, lines and segments) are translated
+into their respective objects.
 
 Next, lines and stations are put together into L<LineStations|Map::Metro::Graph::LineStation>. Every two adjacent LineStations
 are put into two L<Connections|Map::Metro::Graph::Connection> (one for each direction).
@@ -284,45 +282,81 @@ All L<Routes|Map::Metro::Graph::Route> between the two L<Stations|Map::Metro::Gr
 
 =head1 PERFORMANCE
 
-Since 0.2200 performance is less than an issue than it used to be, but it could still be improved. Prior to this version the entire network was analyzed up-front. This is unnecessary when searching one (or a few) routes. For long-running applications it is still possible to pre-calculate all paths, see L<asps|Map::Metro::Graph/"asps()">.
+Since 0.2200 performance is less of an issue than it used to be, but it could still be improved. Prior to that version the entire network was analyzed up-front. This is unnecessary when searching one (or a few) routes. For long-running applications it is still possible to pre-calculate all paths, see L<asps|Map::Metro::Graph/"asps()">.
 
 It is also possible to run the backend to some commands in a server, see L<App::Map::Metro>.
 
 =head1 STATUS
 
 This is somewhat experimental. I don't expect that the map file format will I<break>, but it might be
-extended. Only the documented api should be relied on, though breaking changes might occur.
+extended. Only the documented api should be used, though breaking changes might occur.
 
 For all maps in the Map::Metro::Plugin::Map namespace (unless noted):
 
-* These maps are not an official source. Use accordingly.
+=over 4
 
-* There should be a note regarding what routes the map covers.
+=item *
+
+These maps are not an official source. Use accordingly.
+
+=item *
+
+There should be a note regarding what routes the map covers.
+
+=back
 
 =head1 COMPATIBILITY
 
-Until version 0.2300, Map::Metro required Perl 5.16. Currently, if it is running under 5.16 or greater, it will use C<fc> (instead of C<lc>) for some string comparisons. Depending on the map definition
-this could lead to maps not working properly on pre-5.16 Perls.
+Under Perl 5.16 or greater, C<fc> will be used instead of C<lc> for some string comparisons. Depending on the map definition
+this might lead to some maps not working properly on pre-5.16 Perls.
+
+Prior to version 0.2400, C<Map::Metro> required at least Perl 5.16.
 
 =head1 Map::Metro or Map::Tube?
 
 L<Map::Tube> is the main alternative to C<Map::Metro>. They both have their strong and weak points.
 
-* Map::Tube is faster.
+=over 4
 
-* Map::Tube is more stable: It has been on Cpan for a long time, and is under active development.
+=item *
 
-* Map::Metro has (in my opinion) a better map format.
+Map::Tube is faster.
 
-* Map::Metro supports eg. transfers between stations.
+=item *
 
-* See L<Task::MapMetro::Maps> and L<Task::Map::Tube> for available maps.
+Map::Tube is more stable: It has been on Cpan for a long time, and is under active development.
 
-* It is possible to convert Map::Metro maps into Map::Tube maps using L<map-metro.pl|Map::Metro::Cmd/"map-metro.pl metro_to_tube $city">.
+=item *
+
+Map::Metro has (in my opinion) a better map format.
+
+=item *
+
+Map::Metro supports eg. transfers between stations.
+
+=item *
+
+See L<Task::MapMetro::Maps> and L<Task::Map::Tube> for available maps.
+
+=item *
+
+It is possible to convert Map::Metro maps into Map::Tube maps using L<map-metro.pl|Map::Metro::Cmd/"map-metro.pl metro_to_tube $city">.
+
+=back
 
 =head1 SEE ALSO
 
-L<Map::Tube>
+=over 4
+
+=item *
+
+L<Task::MapMetro::Maps> - Available maps
+
+=item *
+
+L<Map::Tube> - An alternative
+
+=back
 
 =head1 SOURCE
 
